const express = require("express");
const mongoose = require("mongoose");
const cors = require("cors");

const app = express();
const PORT = process.env.PORT || 5000;

app.use(cors());
app.use(express.json());

const uri = "mongodb://localhost:27017/CloudComputing";

//Method to create database connection
mongoose.connect(uri)
    .then(() => console.log('Connection established :)'))
    .catch(err => {
        console.error('Failed to setup the connection to the database', err.message);
        process.exit(1);});

const Template = new mongoose.Schema({
    text: String,
    status: {type: String, default: "open"}
});

const todoTemplate = mongoose.model("todos", Template);

app.listen(PORT, () => console.log(`Server was started on port ${PORT}`));

//Method to fetch all the elements from the database
app.get("/todos", async (req, res) => {
    const fetchesTodos = await todoTemplate.find();
    res.json(fetchesTodos);
});

//Method to add an element to the database
app.post("/todos", async (req, res) => {
    const addedTodo = new todoTemplate({text: req.body.text, status: "open"});
    await addedTodo.save();
    res.json(addedTodo);
});

//Method to update an element within the database
app.patch("/todos/:id", async (req, res) => {
   const todo = await todoTemplate.findByIdAndUpdate(req.params.id, {status: req.body.status}, {new: true});
   res.json(todo);
});

//Method to delete an element from the database
app.delete("/todos/:id", async(req, res) => {
   await todoTemplate.findByIdAndDelete(req.params.id);
   res.json({message: "Element was deleted"});
});



